<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fpoe_kaernten_theme_full_final_v2/html/email.html.twig */
class __TwigTemplate_1f6d1aaf408aee0ba85e6b21c1733bbb extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<mjml>
  <mj-head>
    <mj-preview>Preview Header
    </mj-preview>
    <mj-attributes>
      <mj-all font-family=\"'Helvetica Neue',Arial,'Noto Sans','Liberation Sans',sans-serif\">
      </mj-all>
    </mj-attributes>
    <mj-style inline=\"inline\">
      .section-w-640 &gt; table {
      margin-left: auto !important;
      margin-right: auto !important;
      max-width: 640px !important;
      }
    </mj-style>
  </mj-head>
  <mj-body background-color=\"#F7F7F7\" width=\"740px\">
    <!-- Top bar -->
    <mj-section background-color=\"#FFFFFF\" padding=\"20px 20px 60px 20px\">
      <mj-group>
        <mj-column width=\"70%\" padding=\"0\" vertical-align=\"middle\">
          <mj-text padding=\"0\" font-family=\"'Open Sans', Helvetica, Arial, Sans Serif\" font-size=\"14px\" color=\"#CBCBCB\" font-weight=\"400\">
            <a href=\"{webview_url}\" style=\"color:#0056A2 !important;text-decoration:none;\">ZUR WEBVERSION →</a>.
          </mj-text>
        </mj-column>
        <mj-column width=\"30%\" padding=\"0\" vertical-align=\"middle\">
          <mj-text align=\"right\" padding=\"0\">
            <a href=\"https://www.facebook.com/fpoe.kaernten\" style=\"margin:0 5px 0 0;\"><img src=\"";
        // line 28
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 28, $this->source); })())) . "/assets/fb-white.png"), null, null, true);
        yield "\" width=\"7\" height=\"16\"/></a>
            <a href=\"https://www.instagram.com/fpoe_kaernten/#\" style=\"margin:0 5px 0 0;\"><img src=\"";
        // line 29
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 29, $this->source); })())) . "/assets/ig-white.png"), null, null, true);
        yield "\" width=\"16\" height=\"16\"/></a>
            <a href=\"https://www.youtube.com/user/freiheitlichektn\"><img src=\"";
        // line 30
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 30, $this->source); })())) . "/assets/yt-white.png"), null, null, true);
        yield "\" width=\"23\" height=\"16\"/></a>
          </mj-text>
        </mj-column>
      </mj-group>
    </mj-section>
    <!-- 1st header -->
    <mj-section padding=\"20px\" background-color=\"#FFFFFF\">
      <mj-group>
        <mj-column width=\"25%\" padding=\"0\" vertical-align=\"middle\">
          <mj-image padding=\"0\" href=\"https://www.fpoe.at\" src=\"";
        // line 39
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 39, $this->source); })())) . "/assets/logo.png"), null, null, true);
        yield "\">
          </mj-image>
        </mj-column>
        <mj-column width=\"75%\" padding=\"0\" vertical-align=\"middle\">
          <mj-text padding=\"0\" align=\"right\" color=\"#0056A2\" font-size=\"18px\">
            <p>NEWSLETTER 2025
            </p>
          </mj-text>
        </mj-column>
      </mj-group>
    </mj-section>
    <!-- 2nd header -->
    <mj-section padding=\"20px\" background-color=\"#0056A2\">
      <mj-group>
        <mj-column padding=\"0\" vertical-align=\"middle\">
          <mj-text padding=\"0\" color=\"#FFFFFF\" font-size=\"27px\" line-height=\"30px\">
            Schnell und richtig informiert.
          </mj-text>
        </mj-column>
      </mj-group>
    </mj-section>
    <mj-section padding=\"9px\" background-color=\"#064D8C\" background-url=\"";
        // line 60
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 60, $this->source); })())) . "/assets/top-aktuell.png"), null, null, true);
        yield "\">
    </mj-section>
    <mj-section padding=\"0\" background-color=\"#FFFFFF\" padding-top=\"0px\">
      <mj-column padding=\"0\" vertical-align=\"middle\">
        <mj-image padding=\"0\" href=\"https://www.fpoe.at\" src=\"";
        // line 64
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 64, $this->source); })())) . "/assets/banner1.jpg"), null, null, true);
        yield "\" padding-top=\"0px\" padding-right=\"0px\" padding-left=\"0px\" width=\"800px\">
        </mj-image>
      </mj-column>
    </mj-section>
    <!-- Introduction -->
    <mj-section padding=\"40px 20px\" css-class=\"section-w-640\" background-color=\"#FFFFFF\">
      <mj-column padding=\"0\" vertical-align=\"middle\">
        <mj-text padding=\"0\" color=\"#3A4044\" font-size=\"27px\" line-height=\"30px\">
          <p> ";
        // line 72
        yield " {% TWIG_BLOCK %}{% if lead.lastname is not empty and lead.firstname is not empty and lead.salutation == \"Herr\" %}Lieber {{ lead.firstname }} {{ lead.lastname }}!{% elseif lead.lastname is not empty and lead.firstname is not empty and lead.salutation == \"Frau\" %}Liebe {{ lead.firstname }} {{ lead.lastname }}!{% elseif lead.lastname is not empty and lead.firstname is empty and lead.salutation == \"Herr\" %}Lieber Herr {{ lead.lastname }}!{% elseif lead.lastname is not empty and lead.firstname is empty and lead.salutation == \"Frau\" %}Liebe Frau {{ lead.lastname }}!{% elseif lead.lastname is not empty and lead.firstname is empty %} Hallo!{% else %}Hallo {{ lead.firstname }} {{ lead.lastname }}!{% endif %}{% END_TWIG_BLOCK %}";
        yield "
    </p>
        </mj-text>
        <mj-spacer height=\"32px\">
        </mj-spacer>
        <mj-text padding=\"0\" color=\"#3A4044\" font-size=\"17px\" line-height=\"30px\">
          <p>
            Lorem ipsum dolor sit amet. Eos minus voluptate et doloribus iste et quam quod qui pariatur fuga et odio repudiandae. Ut nihil tempora sed rerum odit ut quos nihil. Aut accusantium fugiat aut maxime recusandae qui iste obcaecati.
          </p>
          <p>
            Est galisum numquam et quia accusantium et similique molestiae eum tenetur iste. Et aspernatur vero ut voluptatem temporibus ut repellendus neque id dolorem dolores sit molestias nostrum aut esse excepturi.
          </p>
          <p>
            <strong>Hans Mustermann</strong>
            <br/>
            Position, Funktion
          </p>
        </mj-text>
      </mj-column>
    </mj-section>
    <!-- Banner -->
    <mj-section padding=\"0 20px\" background-color=\"#FFFFFF\">
      <mj-column padding=\"0\" vertical-align=\"middle\">
        <mj-image padding=\"0\" href=\"https://www.fpoe.at\" src=\"";
        // line 95
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 95, $this->source); })())) . "/assets/banner1.jpg"), null, null, true);
        yield "\">
        </mj-image>
      </mj-column>
    </mj-section>
    <!-- 2-column text w/ image -->
    <mj-section padding=\"20px\" css-class=\"section-w-640\" background-color=\"#FFFFFF\">
      <mj-column width=\"48%\" padding=\"0\">
        <mj-text padding=\"0\" color=\"#3A4044\" font-size=\"17px\" line-height=\"30px\">
          <p>
            <strong>Alle Entschädigungen werden an notleidende Österreicher gespendet.</strong>
          </p>
          <p>
            Dennoch gilt auch für diese Personen: Wer aus sozialen Gründen um Nachsicht ersucht, dem wurde und wird finanziell entgegengekommen. Und generell gilt: „Alle Gelder, die aus den Entschädigungszahlungen eingehen, werden ebenso wie alle anderen gerichtlich zugesprochenen Geldentschädigungen ausschließlich dafür verwendet, Österreicher finanziell zu unterstützen, die durch die katastrophale Politik der Regierung in Not geraten sind“, sagte heute unser FPÖ-Generalsekretär Christian Hafenecker.
          </p>
        </mj-text>
      </mj-column>
      <mj-column width=\"4%\" padding=\"0\">
      </mj-column>
      <mj-column width=\"48%\" padding=\"0\">
        <mj-text padding=\"0\" color=\"#3A4044\" font-size=\"17px\" line-height=\"30px\">
          <p>
            <strong>Der FPÖ und Herbert Kickl geht es darum, dass die falschen und rufschädigenden Behauptungen nicht mehr verbreitet werden.</strong>
          </p>
          <p>
            Dennoch haben nicht alle Facebook-Nutzer, die das getan haben, Post vom Anwalt erhalten, sondern nur etwa 30 von mehreren Hunderten. Diese Personen konnten leicht als Funktionäre, Mitarbeiter oder gar Mandatare anderer Parteien identifiziert werden. Wir konnten daher davon ausgehen, dass sie der FPÖ durch die Verbreitung falscher Behauptungen wissentlich schaden wollten.
          </p>
        </mj-text>
        <mj-button align=\"left\" href=\"https://www.fpoe.at\" padding=\"4px 0px\" border-radius=\"20px\" inner-padding=\"12px 50px\" background-color=\"#0056A2\" font-size=\"17px\">Mehr zu diesem Thema
        </mj-button>
      </mj-column>
    </mj-section>
    <!-- Divider -->
    <mj-section padding=\"0 20px\" background-color=\"#FFFFFF\">
      <mj-column padding=\"0\" vertical-align=\"middle\">
        <mj-divider padding=\"50px\" border-width=\"1px\" border-color=\"#F2F2F2\">
        </mj-divider>
      </mj-column>
    </mj-section>
    <!-- Banner -->
    <mj-section padding=\"0 20px\" background-color=\"#FFFFFF\">
      <mj-column padding=\"0\" vertical-align=\"middle\">
        <mj-image href=\"https://example.com\" src=\"";
        // line 136
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 136, $this->source); })())) . "/assets/fanshop.jpg"), null, null, true);
        yield "\" padding=\"0\" css-class=\"banner-img desktopContent\">
        </mj-image>
      </mj-column>
    </mj-section>
    <!-- Divider -->
    <mj-section padding=\"0 20px\" background-color=\"#FFFFFF\">
      <mj-column padding=\"0\" vertical-align=\"middle\">
        <mj-divider padding=\"50px\" border-width=\"1px\" border-color=\"#F2F2F2\">
        </mj-divider>
      </mj-column>
    </mj-section>
    <!-- 2-column text w/ button -->
    <mj-section padding=\"0 20px\" background-color=\"#FFFFFF\">
      <mj-column width=\"50%\" padding=\"30px\" background-color=\"#F7F7F7\">
        <mj-text padding=\"0\" color=\"#3A4044\" font-size=\"27px\" line-height=\"30px\">
          Nächstes Thema Lorem ipsum Dolor.
        </mj-text>
        <mj-text padding=\"0\" color=\"#3A4044\" font-size=\"17px\" line-height=\"30px\">
          <p>
            Wenig hat man nämlich im Mainstream auch über die „Klagsorgie“ der Kanzlergattin Katharina Nehammer erfahren. Sie hat nicht 30, sondern bis zu 1000 Nutzer verfolgen lassen.
            <br/>
            <br/>
            <strong><a href=\"#\" style=\"color:#0056A2;text-decoration:none;\">▶ Zum Video</a></strong>
          </p>
        </mj-text>
      </mj-column>
      <mj-column width=\"50%\" padding=\"0\">
        <mj-image padding=\"0\" src=\"";
        // line 163
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 163, $this->source); })())) . "/assets/banner3.png"), null, null, true);
        yield "\">
        </mj-image>
      </mj-column>
    </mj-section>
    <!-- Divider -->
    <mj-section padding=\"0 20px\" background-color=\"#FFFFFF\">
      <mj-column padding=\"0\" vertical-align=\"middle\">
        <mj-divider padding=\"50px\" border-width=\"1px\" border-color=\"#F2F2F2\">
        </mj-divider>
      </mj-column>
    </mj-section>
    <!-- Introduction -->
    <mj-section padding=\"0 20px\" css-class=\"section-w-640\" background-color=\"#FFFFFF\">
      <mj-column padding=\"0\" vertical-align=\"middle\">
        <mj-text padding=\"0\" align=\"center\" color=\"#0056A2\" font-size=\"27px\" line-height=\"30px\">
          Unterstütze unsere Initiativen
        </mj-text>
        <mj-text padding=\"0\" align=\"center\" color=\"#3A4044\" font-size=\"17px\" line-height=\"30px\">
          Unterstütze auch Du unsere Online-Petition und lade Deine Familie und Freunde ein, gemeinsam mit uns das Bargeld zu schützen:
        </mj-text>
        <mj-image padding=\"0\" src=\"";
        // line 183
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 183, $this->source); })())) . "/assets/banner6.jpg"), null, null, true);
        yield "\">
        </mj-image>
        <mj-spacer height=\"32px\">
        </mj-spacer>
        <mj-button href=\"https://www.fpoe.at\" padding=\"4px 0px\" border-radius=\"20px\" inner-padding=\"12px 50px\" background-color=\"#0056A2\" font-size=\"17px\">
          <p>JETZT UNTERSCHREIBEN
          </p>
        </mj-button>
        <mj-spacer height=\"32px\">
        </mj-spacer>
        <mj-spacer height=\"32px\">
        </mj-spacer>
      </mj-column>
    </mj-section>
    <!-- Divider -->
    <mj-section padding=\"0 20px\" background-color=\"#FFFFFF\">
      <mj-column padding=\"0\" vertical-align=\"middle\">
        <mj-divider padding=\"50px\" border-width=\"1px\" border-color=\"#F2F2F2\">
        </mj-divider>
      </mj-column>
    </mj-section>
    <!-- 2-column images -->
    <mj-section padding=\"20px\" css-class=\"section-w-640\" background-color=\"#FFFFFF\">
      <mj-column width=\"48%\" padding=\"0\">
        <mj-image padding=\"0\" src=\"";
        // line 207
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 207, $this->source); })())) . "/assets/banner7.jpg"), null, null, true);
        yield "\">
        </mj-image>
      </mj-column>
      <mj-column width=\"4%\" padding=\"0\">
      </mj-column>
      <mj-column width=\"48%\" padding=\"0\">
        <mj-image padding=\"0\" src=\"";
        // line 213
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 213, $this->source); })())) . "/assets/banner5.jpg"), null, null, true);
        yield "\">
        </mj-image>
      </mj-column>
    </mj-section>
    <!-- Divider -->
    <!-- 2-column text w/ image -->
    <!-- Divider -->
    <mj-section padding=\"0 20px\" background-color=\"#FFFFFF\">
      <mj-column padding=\"0\" vertical-align=\"middle\">
        <mj-divider padding=\"50px\" border-width=\"1px\" border-color=\"#F2F2F2\">
        </mj-divider>
      </mj-column>
    </mj-section>
    <!-- Banner -->
    <mj-section padding=\"0 20px\" background-color=\"#FFFFFF\">
      <mj-column padding=\"0\" vertical-align=\"middle\">
        <mj-image href=\"https://example.com\" src=\"";
        // line 229
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 229, $this->source); })())) . "/assets/newsletter.png"), null, null, true);
        yield "\" padding=\"0\" css-class=\"banner-img desktopContent\" padding-bottom=\"20px\">
        </mj-image>
      </mj-column>
    </mj-section>
    <mj-section padding=\"0px\" background-color=\"#FFFFFF\" padding-bottom=\"0px\">
      <mj-column padding=\"0\" vertical-align=\"middle\">
        <mj-image href=\"https://www.fpoe.at\" src=\"";
        // line 235
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 235, $this->source); })())) . "/assets/logo.png"), null, null, true);
        yield "\" padding=\"0\" padding-bottom=\"0px\" padding-right=\"0px\" padding-left=\"0px\" width=\"800px\">
        </mj-image>
      </mj-column>
    </mj-section>
    <!-- Divider -->
    <!-- Footer -->
    <mj-section padding=\"15px 20px\" background-color=\"#0056A2\">
      <mj-group>
        <mj-column width=\"20%\" padding=\"0\" vertical-align=\"middle\">
          <mj-image href=\"https://www.fpoe.at\" src=\"";
        // line 244
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 244, $this->source); })())) . "/assets/logo.png"), null, null, true);
        yield "\" align=\"left\" width=\"70px\" padding=\"0\">
          </mj-image>
        </mj-column>
        <mj-column width=\"80%\" padding=\"0\" vertical-align=\"middle\">
          <mj-text align=\"right\" padding=\"0\">
            <a href=\"https://www.facebook.com/fpoe.kaernten\" style=\"margin:0 5px 0 0;\"><img src=\"";
        // line 249
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 249, $this->source); })())) . "/assets/fb-white.png"), null, null, true);
        yield "\" width=\"7\" height=\"16\"/></a>
            <a href=\"https://www.instagram.com/fpoe_kaernten/#\" style=\"margin:0 5px 0 0;\"><img src=\"";
        // line 250
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 250, $this->source); })())) . "/assets/ig-white.png"), null, null, true);
        yield "\" width=\"16\" height=\"16\"/></a>
            <a href=\"https://www.youtube.com/user/freiheitlichektn\"><img src=\"";
        // line 251
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 251, $this->source); })())) . "/assets/yt-white.png"), null, null, true);
        yield "\" width=\"23\" height=\"16\"/></a>
          </mj-text>
        </mj-column>
      </mj-group>
    </mj-section>
    <mj-section padding=\"20px\" background-color=\"#FFFFFF\">
      <mj-column padding=\"0\">
        <mj-text padding=\"10px\" color=\"#0056A2\" font-size=\"14px\" line-height=\"20px\">
          <strong>Die Freiheitlichen in Kärnten (FPÖ)</strong>
          <br/>
          Dr.-Franz-Palla-Gasse 1
          <br/>
          9020 Klagenfurt am Wörthersee\t
        </mj-text>
      </mj-column>
      <mj-column padding=\"0\">
        <mj-text padding=\"10px\" color=\"#0056A2\" font-size=\"14px\" line-height=\"20px\">
          <img src=\"";
        // line 268
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 268, $this->source); })())) . "/assets/mail-icon.png"), null, null, true);
        yield "\" width=\"15\" height=\"xxx\" alt=\"\" style=\"margin-right:5px;\"/>
          <a href=\"mailto:office@freiheitliche-ktn.at\" style=\"color:#0056A2 !important;text-decoration:none;\">office@freiheitliche-ktn.at</a>
          <br/>
          <img src=\"";
        // line 271
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 271, $this->source); })())) . "/assets/phone-icon.png"), null, null, true);
        yield "\" width=\"15\" height=\"xxx\" alt=\"\" style=\"margin-right:5px;\"/>
          <a href=\"tel:+43140575600\" style=\"color:#0056A2 !important;text-decoration:none;\">+43-463-56404</a>
          <br/>
          <img src=\"";
        // line 274
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 274, $this->source); })())) . "/assets/complianz-icon.png"), null, null, true);
        yield "\" width=\"15\" height=\"xxx\" alt=\"\" style=\"margin-right:5px;\"/>
          <a href=\"https://www.fpoe-ktn.at/\" style=\"color:#0056A2 !important;text-decoration:none;\">fpoe.at/datenschutz</a>
        </mj-text>
      </mj-column>
      <mj-column padding=\"0\">
        <mj-text padding=\"10px\" color=\"#0056A2\" font-size=\"14px\" line-height=\"20px\">
          <a href=\"https://www.fpoe-ktn.at/impressum/\" style=\"color:#0056A2 !important;text-decoration:none;\">Impressum</a>
          <br/>
          <a href=\"https://www.fpoe-ktn.at/datenschutz/\" style=\"color:#0056A2 !important;text-decoration:none;\">Datenschutz</a>
        </mj-text>
      </mj-column>
    </mj-section>
    <mj-section padding=\"20px\" css-class=\"section-w-640\" background-color=\"#FFFFFF\">
      <mj-column padding=\"0\">
        <mj-image href=\"https://www.fpoe.at\" src=\"";
        // line 288
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 288, $this->source); })())) . "/assets/logo.png"), null, null, true);
        yield "\" width=\"72px\" padding=\"0\">
        </mj-image>
        <mj-text padding=\"10px 0\" align=\"center\" color=\"#CBCBCB\" font-size=\"14px\" line-height=\"20px\">
          <a href=\"https://gemeinsam.fpoe.at/datenaktualisierung?uuid={contactfield=uuid}\" style=\"color:#0056A2 !important;text-decoration:none;\">
                <!-- FINAL_IMAGE_BEFORE_FOOTER -->
                <mj-section padding=\"0\">
                  <mj-column>
                    <mj-image padding=\"0\" src=\"";
        // line 295
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->getAssetUrl((("themes/" . (isset($context["template"]) || array_key_exists("template", $context) ? $context["template"] : (function () { throw new RuntimeError('Variable "template" does not exist.', 295, $this->source); })())) . "/assets/banner4.jpg"), null, null, true);
        yield "\"></mj-image>
                  </mj-column>
                </mj-section>
                Kontaktdaten anpassen / Abmelden</a>
        </mj-text>
      </mj-column>
    </mj-section>
  </mj-body>
</mjml>";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fpoe_kaernten_theme_full_final_v2/html/email.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  407 => 295,  397 => 288,  380 => 274,  374 => 271,  368 => 268,  348 => 251,  344 => 250,  340 => 249,  332 => 244,  320 => 235,  311 => 229,  292 => 213,  283 => 207,  256 => 183,  233 => 163,  203 => 136,  159 => 95,  133 => 72,  122 => 64,  115 => 60,  91 => 39,  79 => 30,  75 => 29,  71 => 28,  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fpoe_kaernten_theme_full_final_v2/html/email.html.twig", "/var/www/html/mauticGIT-Test/themes/fpoe_kaernten_theme_full_final_v2/html/email.html.twig");
    }
}
